package javax.swing.plaf.synth;

import java.beans.PropertyChangeEvent;
import java.awt.Dimension;
import javax.swing.Icon;
import java.awt.Graphics;
import java.awt.FontMetrics;
import java.awt.Insets;
import javax.swing.plaf.basic.BasicHTML;
import javax.swing.text.View;
import java.awt.Rectangle;
import javax.swing.JLabel;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.basic.BasicLabelUI;

public class SynthLabelUI extends BasicLabelUI implements SynthUI
{
    private SynthStyle style;
    
    public SynthLabelUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthLabelUI();
    }
    
    @Override
    protected void installDefaults(JLabel label) {
        this.updateStyle(label);
    }
    
    void updateStyle(JLabel label) {
        SynthContext context = this.getContext(label, 1);
        this.style = SynthLookAndFeel.updateStyle(context, this);
        context.dispose();
    }
    
    @Override
    protected void uninstallDefaults(JLabel label) {
        SynthContext context = this.getContext(label, 1);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, this.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    private int getComponentState(JComponent component) {
        int componentState = SynthLookAndFeel.getComponentState(component);
        if (SynthLookAndFeel.getSelectedUI() == this && componentState == 1) {
            componentState = (SynthLookAndFeel.getSelectedUIState() | 0x1);
        }
        return componentState;
    }
    
    @Override
    public int getBaseline(JComponent component, int n, int n2) {
        if (component == null) {
            throw new NullPointerException("Component must be non-null");
        }
        if (n < 0 || n2 < 0) {
            throw new IllegalArgumentException("Width and height must be >= 0");
        }
        JLabel label = (JLabel)component;
        String text = label.getText();
        if (text == null || "".equals(text)) {
            return -1;
        }
        Insets insets = label.getInsets();
        Rectangle rectangle = new Rectangle();
        Rectangle rectangle2 = new Rectangle();
        Rectangle rectangle3 = new Rectangle();
        rectangle.x = insets.left;
        rectangle.y = insets.top;
        rectangle.width = n - (insets.right + rectangle.x);
        rectangle.height = n2 - (insets.bottom + rectangle.y);
        SynthContext context = this.getContext(label);
        FontMetrics fontMetrics = context.getComponent().getFontMetrics(context.getStyle().getFont(context));
        context.getStyle().getGraphicsUtils(context).layoutText(context, fontMetrics, label.getText(), label.getIcon(), label.getHorizontalAlignment(), label.getVerticalAlignment(), label.getHorizontalTextPosition(), label.getVerticalTextPosition(), rectangle, rectangle3, rectangle2, label.getIconTextGap());
        View view = (View)label.getClientProperty("html");
        int htmlBaseline;
        if (view != null) {
            htmlBaseline = BasicHTML.getHTMLBaseline(view, rectangle2.width, rectangle2.height);
            if (htmlBaseline >= 0) {
                htmlBaseline += rectangle2.y;
            }
        }
        else {
            htmlBaseline = rectangle2.y + fontMetrics.getAscent();
        }
        context.dispose();
        return htmlBaseline;
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        context.getPainter().paintLabelBackground(context, graphics, 0, 0, component.getWidth(), component.getHeight());
        this.paint(context, graphics);
        context.dispose();
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics graphics) {
        JLabel label = (JLabel)synthContext.getComponent();
        Icon icon = label.isEnabled() ? label.getIcon() : label.getDisabledIcon();
        graphics.setColor(synthContext.getStyle().getColor(synthContext, ColorType.TEXT_FOREGROUND));
        graphics.setFont(this.style.getFont(synthContext));
        synthContext.getStyle().getGraphicsUtils(synthContext).paintText(synthContext, graphics, label.getText(), icon, label.getHorizontalAlignment(), label.getVerticalAlignment(), label.getHorizontalTextPosition(), label.getVerticalTextPosition(), label.getIconTextGap(), label.getDisplayedMnemonicIndex(), 0);
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintLabelBorder(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        JLabel label = (JLabel)component;
        Icon icon = label.isEnabled() ? label.getIcon() : label.getDisabledIcon();
        SynthContext context = this.getContext(component);
        Dimension preferredSize = context.getStyle().getGraphicsUtils(context).getPreferredSize(context, context.getStyle().getFont(context), label.getText(), icon, label.getHorizontalAlignment(), label.getVerticalAlignment(), label.getHorizontalTextPosition(), label.getVerticalTextPosition(), label.getIconTextGap(), label.getDisplayedMnemonicIndex());
        context.dispose();
        return preferredSize;
    }
    
    @Override
    public Dimension getMinimumSize(JComponent component) {
        JLabel label = (JLabel)component;
        Icon icon = label.isEnabled() ? label.getIcon() : label.getDisabledIcon();
        SynthContext context = this.getContext(component);
        Dimension minimumSize = context.getStyle().getGraphicsUtils(context).getMinimumSize(context, context.getStyle().getFont(context), label.getText(), icon, label.getHorizontalAlignment(), label.getVerticalAlignment(), label.getHorizontalTextPosition(), label.getVerticalTextPosition(), label.getIconTextGap(), label.getDisplayedMnemonicIndex());
        context.dispose();
        return minimumSize;
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        JLabel label = (JLabel)component;
        Icon icon = label.isEnabled() ? label.getIcon() : label.getDisabledIcon();
        SynthContext context = this.getContext(component);
        Dimension maximumSize = context.getStyle().getGraphicsUtils(context).getMaximumSize(context, context.getStyle().getFont(context), label.getText(), icon, label.getHorizontalAlignment(), label.getVerticalAlignment(), label.getHorizontalTextPosition(), label.getVerticalTextPosition(), label.getIconTextGap(), label.getDisplayedMnemonicIndex());
        context.dispose();
        return maximumSize;
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent e) {
        super.propertyChange(e);
        if (SynthLookAndFeel.shouldUpdateStyle(e)) {
            this.updateStyle((JLabel)e.getSource());
        }
    }
}
